@@ -394,7 +394,11 @@ def snakemake(
 
     # force thread use for any kind of cluster
     use_threads = (
-        force_use_threads or (os.name != "posix") or cluster or cluster_sync or drmaa
+        force_use_threads
+        or (os.name not in ["posix", "nt"])
+        or cluster
+        or cluster_sync
+        or drmaa
     )
 
     if not keep_logger:
