@@ -52,6 +52,9 @@ class ProvenanceHashMap:
         elif job.is_script:
             _, source, _ = script.get_source(job.rule.script)
             h.update(source)
+        elif job.is_notebook:
+            _, source, _ = script.get_source(job.rule.notebook)
+            h.update(source)
         elif job.is_wrapper:
             _, source, _ = script.get_source(
                 wrapper.get_script(job.rule.wrapper, prefix=workflow.wrapper_prefix)
@@ -79,15 +82,13 @@ class ProvenanceHashMap:
                     e,
                 )
 
-        # Hash input files that are not generated by other jobs.
-        for f in job.input:
-            if not any(
-                f in depfiles for depfiles in job.dag.dependencies[job].values()
-            ):
-                with open(f, "b") as f:
-                    # Read and update hash string value in blocks of 4K
-                    for byte_block in iter(lambda: f.read(4096), b""):
-                        h.update(byte_block)
+        # Hash input files that are not generated by other jobs (sorted by hash value).
+        for file_hash in sorted(
+            hash_file(f)
+            for f in job.input
+            if not any(f in depfiles for depfiles in job.dag.dependencies[job].values())
+        ):
+            h.update(file_hash.encode())
 
         # Hash used containers or conda environments.
         if workflow.use_conda and job.conda_env:
@@ -97,7 +98,7 @@ class ProvenanceHashMap:
         elif workflow.use_singularity and job.container_img_url:
             h.update(job.container_img_url.encode())
 
-        # Generate hashes of dependencies, and add them in a blockchain fashion (as input to the current hash).
+        # Generate hashes of dependencies, and add them in a blockchain fashion (as input to the current hash, sorted by hash value).
         for dep_hash in sorted(
             self._get_provenance_hash(dep)
             for dep in set(job.dag.dependencies[job].keys())
@@ -110,3 +111,12 @@ class ProvenanceHashMap:
         self._hashes[job] = provenance_hash
 
         return provenance_hash
+
+
+def hash_file(f):
+    h = hashlib.sha256()
+    with open(f, "b") as f:
+        # Read and update hash string value in blocks of 4K
+        for byte_block in iter(lambda: f.read(4096), b""):
+            h.update(byte_block)
+    return h.hexdigest()
